@@ -113,8 +113,8 @@ class Cursor:
         request_generator = self._generate_requests(size)
         for response in self._client.stream_requests(request_generator):
             if response.status.code == core_pb2.Status.StatusCode.Value("ERROR"):
-                execption = bool(response.status.details) and response.status.details[0].exception
-                error_msg = execption or "Unknown error when fetching results."
+                exception = bool(response.status.details) and response.status.details[0].exception
+                error_msg = exception or response.status.description or "Unknown error when fetching results."
                 raise RuntimeError(error_msg)
 
             for elem in self._parse_response_fn(response):
@@ -158,7 +158,7 @@ class Connection:
     """
 
     def __init__(self, host: str, port: int, api_key: str = None, service_name: str = None, timeout: int = 0,
-                 response_timeout: int = 2, traceroute: bool = False):
+                 response_timeout: int = 20, traceroute: bool = False):
         """
         :param host: service host
         :type host: str
@@ -170,7 +170,7 @@ class Connection:
         :type service_name: str, optional
         :param timeout: defaults to 0. Timeout to retry connection if gRPC is unavailable. 0 is no retry.
         :type timeout: int, optional
-        :param response_timeout: defaults to 2 seconds. Fail if gateway doesn't receive response within timeout.
+        :param response_timeout: defaults to 20 seconds. Fail if gateway doesn't receive response within timeout.
         :type response_timeout: int, optional
         :param traceroute: Whether to send receipts back to the gateway from each stage of the graph
         :type traceroute: bool, optional
@@ -339,7 +339,8 @@ class Connection:
         self.grpc.secure = is_secure
 
 
-def connect(service_name: str = None, router_name: str = None, timeout: int = 0) -> Connection:
+def connect(service_name: str = None, router_name: str = None, timeout: int = 0,
+            response_timeout: int = 20, traceroute: bool = False) -> Connection:
     """Connects to a live service/router and returns an instance of :class:`Connection`.
 
     :param service_name: name of a service.
@@ -348,6 +349,12 @@ def connect(service_name: str = None, router_name: str = None, timeout: int = 0)
     :type router_name: str
     :param timeout: gRPC connection timeout, defaults to 0
     :type timeout: int, optional
+    :param timeout: defaults to 0. Timeout to retry connection if gRPC is unavailable. 0 is no retry.
+    :type timeout: int, optional
+    :param response_timeout: defaults to 20 seconds. Fail if gateway doesn't receive response within timeout.
+    :type response_timeout: int, optional
+    :param traceroute: Whether to send receipts back to the gateway from each stage of the graph
+    :type traceroute: bool, optional
     :return: :class:`Connection`
     """
     api_cls = RouterAPI if router_name else ControllerAPI
@@ -359,5 +366,5 @@ def connect(service_name: str = None, router_name: str = None, timeout: int = 0)
 
     host = status.get("host") or Config.CONTROLLER_HOST.split("://")[1].split(":")[0]
     port = status.get("port")
-    return Connection(host=host, port=port,
-                      api_key=Config.API_KEY, service_name=dest_name, timeout=timeout)
+    return Connection(host=host, port=port, api_key=Config.API_KEY, service_name=dest_name,
+                      timeout=timeout, response_timeout=response_timeout, traceroute=traceroute)
