@@ -30,7 +30,7 @@ if __name__ == '__main__':
     executor = concurrent.futures.ThreadPoolExecutor()
 
     async def call_handler(msg):
-        loop = asyncio.get_running_loop()
+        loop = asyncio.get_event_loop()
         return await loop.run_in_executor(executor, partial(transformer_service.handle_msg, msg))
 
     in_sockets = [Socket(True, SocketType.PULL, port=constants.ZMQ_PORT_IN)]
