@@ -55,7 +55,7 @@ class Ranker (Function):
         elif len(orig_data) == 0:
             orig.CopyFrom(dump_numpy(new_data))
         else:
-            new.CopyFrom(dump_numpy(
+            orig.CopyFrom(dump_numpy(
                 np.concatenate((orig_data, new_data))))
     @staticmethod
     def merge_query_msg(orig: 'core_pb2.Request', msg: 'core_pb2.Request') -> 'core_pb2.Request':
@@ -64,6 +64,7 @@ class Ranker (Function):
             orig_matches.scores.extend(new_matches.scores)
             if orig.query.include_data:
                 Ranker.merge_nd_arrays(orig_matches.data, new_matches.data)
+
         orig.routes.append(msg.routes.pop(-1))
         return orig
 
@@ -96,7 +97,7 @@ class Ranker (Function):
             sorted_ids = [matches.ids[int(i)] for i in topk_idx]
             sorted_scores = [scores[int(i)] for i in topk_idx]
             if len(embeddings) > 0 and query.include_data:
-                sorted_embeddings = dump_numpy(embeddings[topk_idx])
+                sorted_embeddings = dump_numpy(embeddings[topk_idx, :])
                 matches.CopyFrom(core_pb2.ScoredResults(
                     ids=sorted_ids, scores=sorted_scores, data=sorted_embeddings))
             else:
