@@ -13,10 +13,13 @@ class CosineRanker(Ranker):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-    def batch_norm(self, xx):
-        xx_row_norms = np.sqrt(np.einsum('ij,ij->i', xx, xx))
+    def batch_norm(self, x):
+        xx_row_norms = np.sqrt(np.einsum('ij,ij->i', x, x))
         xx_row_norms[xx_row_norms == 0] = 1  # don't normalize zero vectors
-        return xx / np.broadcast_to(xx_row_norms, (xx.shape[1],) + xx_row_norms.shape).T
+        return x / xx_row_norms[:, np.newaxis]
+
+    def norm(self, q):
+        return q / np.sqrt(np.einsum('ij,ij->i', q, q))
 
     def sim_cosine(self, x, u):
         norm_x = np.sqrt(np.einsum('i,i->', x, x))
@@ -24,10 +27,10 @@ class CosineRanker(Ranker):
         ret = np.einsum('i,i->', x, u) / (norm_x * norm_u)
         return ret
 
-    def batch_cosine(self, xx, uu):
-        xx_normed = self.batch_norm(xx)
-        uu_normed = self.batch_norm(uu)
-        return np.einsum('ij,kj->ik', xx_normed, uu_normed)
+    def batch_cosine(self, x, q):
+        x_normed = self.batch_norm(x)
+        q_normed = self.norm(q)
+        return np.einsum('ij,kj->ik', x_normed, q_normed)
 
     def score(self, q: np.ndarray, vectors: np.ndarray, prev_scores: Iterable[float]) -> Iterable[float]:
         return self.batch_cosine(vectors, q).flatten()
