@@ -15,9 +15,10 @@ class EuclideanRanker(Ranker):
 
     def batch_euclidean(self, xx, uu):
         xx_normed_squared = np.einsum('ij,ij->i', xx, xx)
-        uu_normed_sqaured = np.einsum('ij,ij->i', uu, uu)
-        return - xx_normed_squared - uu_normed_sqaured + 2 * np.dot(xx, np.transpose(uu))
+        uu_normed_squared = np.einsum('ij,ij->i', uu, uu)
+        dot_product = np.einsum('ij,kj->ik', xx, uu)
+        return -xx_normed_squared[:, np.newaxis] - uu_normed_squared + 2 * dot_product
     
 
     def score(self, q: np.ndarray, vectors: np.ndarray, prev_scores: Iterable[float]) -> Iterable[float]:
-        return self.batch_euclidean(q, vectors).flatten()
+        return self.batch_euclidean(vectors, q).flatten()
