@@ -26,9 +26,10 @@ class GRPCClient:
         api_key: str = None,
         secure: bool = True,
         service_name: str = None,
-        timeout: int = 30,
+        timeout: int = 2,
         conn_timeout: int = 1,
-        traceroute: bool = False
+        traceroute: bool = False,
+        reuse_channel: bool = True
     ):
         self.host = host
         self.port = port
@@ -37,20 +38,25 @@ class GRPCClient:
         self.timeout = timeout
         self.traceroute = traceroute
         self.conn_timeout = conn_timeout
+        self.reuse_channel = reuse_channel
+        self._channel = None
         atexit.register(_clean_up_client, client=self)
 
     @property
     def channel(self):
         """Creates GRPC channel."""
-        target = "{}:{}".format(self.host, self.port)
-        if not self.secure:
-            return grpc.insecure_channel(target, options=(("grpc.max_send_message_length", MAX_MSG_SIZE),
-                                                          ("grpc.max_receive_message_length", MAX_MSG_SIZE),))
-
-        tls = grpc.ssl_channel_credentials()
-        return grpc.secure_channel(target, tls, options=(("grpc.ssl_target_name_override", self.host),
-                                                         ("grpc.max_send_message_length", MAX_MSG_SIZE),
-                                                         ("grpc.max_receive_message_length", MAX_MSG_SIZE),))
+        def _gen():
+            target = "{}:{}".format(self.host, self.port)
+            options = (("grpc.max_send_message_length", MAX_MSG_SIZE),
+                       ("grpc.max_receive_message_length", MAX_MSG_SIZE),)
+            if not self.secure:
+                return grpc.insecure_channel(target, options=options)
+            tls = grpc.ssl_channel_credentials()
+            return grpc.secure_channel(target, tls, options=(("grpc.ssl_target_name_override", self.host),) + options)
+        if self.reuse_channel and self._channel:
+            return self._channel
+        self._channel = _gen()
+        return self._channel
 
     def get_index_request(
         self,
